@@ -1,10 +1,11 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Rope::Object;
-my (%META, %PRO);
+my (%META);
+our (%PRO);
 BEGIN {
 	%PRO = (
 		keyword => sub {
@@ -183,7 +184,7 @@ Rope - The great new Rope!
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -207,6 +208,7 @@ Perhaps a little code snippet.
 
 	properties {
 		bends => {
+			type => sub { $_[0] =~ m/^\d+$/ ? $_[0] : die "$_[0] != integer" },
 			value => 10,
 			writeable => 0,
 			configurable => 1,
@@ -230,7 +232,7 @@ Perhaps a little code snippet.
 	
 	$k->{add_loops}(5);
 
-	say $k->{loops}; # 5;
+	say $k->{loops}; # 6;
 
 	$k->{add_loops} = 5; # errors
 
